package ctree;

/**
 * A buffered page stored in {@link LRUBuffer} and returned by {@link ctree.LRUBuffer#find}.
 * Besides the page itself, the returned element also
 * specifies the nodeType and whether the node was parsed. If parsed, the returned
 * object is of class DBPage.  Otherwise, the returned object is a byte array and
 * it's up to the application to generate a DBPage object.
 * 
 * @see LRUBuffer
 * @author Mikalai Tsytsarau;
 */

public class CBufferElement implements Comparable {
    //pin count
    public int pinCount;
    //whether dirty
    public boolean dirty;
    //page ID
    public int pageID;
    // last used time
    public long time;

    public int hashCode() {
        return pageID;
    }
    public boolean equals(java.lang.Object o) {
        if (o.getClass() == Integer.class) {
            return ((Integer) o) == pageID;
        }
        return o.hashCode() == pageID;
    }
    public int compareTo(Object o) {
        return -(int)Math.signum(this.time - ((CBufferElement) o).time);
    }

    /**
     * stored object.
     * If parsed, it is a DBPage; otherwise it is a byte[].
     */
    public Object object;
    /**
     * whether the page has been parsed by the application
     */
    public boolean parsed;
    /**
     * type of node.
     * -1 means DBByteArrayPage. 0 means DBEmptyPage.
     * Other values should be explained by the application.
     */
    public int nodeType;

    public CBufferElement() {
        pinCount = 0;
        dirty = false;
        pageID = 0;
        object = null;
        parsed = false;
        nodeType = 0;
    }
	
	public CBufferElement(int _nodeType, Object _object, boolean _parsed) {
		nodeType = _nodeType;
		object = _object;
		parsed = _parsed;
	}
}
