package database;


import java.sql.*;
import java.util.Properties;


public class DatabaseAccess {
    protected static Properties properties;

    protected static Connection connection;
    protected static DB database;

    public static void init(Properties props) throws Exception {
        if (connection == null) {
            database = new DB(props);
            if (Boolean.parseBoolean(props.getProperty("active"))) {
                database.connectToDatabase();
                connection = database.getConnection();
            }
        }
        properties = props;

    }

    public static void init(String user, String password, String url, String driver) throws Exception {
		// create DB object: access to Database
		database = new DB(user, password, url, driver);
        database.connectToDatabase();
        connection = database.getConnection();
	}

    public static void init(Connection _connection) {
        connection = _connection;
    }

    public static boolean initialized() {
        return connection != null;
    }

    public static void deleteTable(String tableName) {
        String query = "DROP table IF EXISTS " + tableName + ";";
        executeUpdate(query);
    }

    public static void executeUpdate(String query){
        try {
            PreparedStatement stm = connection.prepareStatement(query);
            stm.executeUpdate();
        }
        catch (SQLException e) {
            System.err.println("Could not execute Query: " + query + " \t" + e.toString());
        }
    }

    public static ResultSet executeQuery(String query){
        try {
            PreparedStatement stm = connection.prepareStatement(query);
            return stm.executeQuery();
        }
        catch (SQLException e) {
            System.err.println("Could not execute Query: " + query + " \t" + e.toString());
            return null;
        }
    }

    public static Statement getDatabaseStatement() {
        if (connection != null) {
            try {
                return connection.createStatement();
            } catch (SQLException e) {
                e.printStackTrace();
            }
        }
        return null;
    }

    public static Connection getConnection() {
        return connection;
    }
}
