package main;

/**
 * A class for 1-st and 2-nd order sentiment moments
 *
 * @author Mikalai Tsytsarau;
 */

import java.io.Serializable;

public class Values implements Serializable, Cloneable {
    public float n = 0f; // number of sentiments, num(s)
    public float m1 = 0f; // first-order moment of sentiments, sum(s)
    public float m2 = 0f; // second-order moment of sentiments, sum(s*s)
    public short np = 0;
    public short nn = 0;
    public short no = 0;

    public Values() {

    }

    public Values(float n, float m1, float m2) {
        this.n = n;
        this.m1 = m1;
        this.m2 = m2;
    }

    public void update(float v) {
        update(v, 1);
    }

    /**
     * Adds the weighted value to the aggregates
     * @param v value to add
     * @param weight weight of the value, can be signed
     */
    public void update(float v, float weight) {
        if (!Float.isNaN(v) && !Float.isInfinite(v)) {
            this.n += weight;
            this.m1 += v * weight;
            this.m2 += v * v * weight;
        }
    }

    public void update(Values v) {
        update(v, 1);
    }

    public void update(Values values, float weight) {
        n += values.n * weight;
        m1 += values.m1 * weight;
        m2 += values.m2 * weight;
        np += values.np; nn += values.nn; no += values.no;
    }

    public float getAvg() {
         return (n <= 0) ? Float.NaN : m1 / n;
    }

    public float getVar() {
        return (n <= 0) ? Float.NaN : (m2 - m1 * m1 / n) / n;
    }

    public float getStdev() {
        return (n <= 0) ? Float.NaN : (float) Math.sqrt((m2 - m1 * m1 / n) / n);
    }

    public void normalize() {
        if (n != 0) { // if n == 0 we assume m1 and m2 also == 0
            n = 1;
            m1 = m1 / n;
            m2 = m2 / n;
        }
    }

    public Values clone() {
        return new Values(n, m1, m2);
    }
}
